import 'babel-polyfill'
import Vue from 'vue'

import Cookies from 'js-cookie'

import 'normalize.css/normalize.css' // a modern alternative to CSS resets

import Element from 'element-ui'

import 'element-ui/lib/theme-chalk/index.css'
import '@/styles/index.scss' // global css
// import '@/assets/samples.css'
import '@/assets/iconfont/iconfont.css'
// 引入文档样式
import '@/assets/doc.css'

import App from './App'
import store from './store'
import router from './router'

import './icons' // icon
// import './permission' // permission control
import './utils/error-log' // error log

import * as filters from './filters' // global filters

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */
// import { mockXHR } from '../mock'
// if (process.env.NODE_ENV === 'production') {
//   mockXHR()
// }

Vue.use(Element, {
  size: Cookies.get('size') || 'medium' // set element-ui default size
})

// 文档需要的高亮代码样式
import VueHighlightJS from 'vue-highlightjs'
import 'highlight.js/styles/github.css'
Vue.use(VueHighlightJS)

import { ImgUpload } from 'packages'
Vue.use(ImgUpload)

// register global utility filters
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})

const whiteList = ['/login', '/404', '/401']

// tags
// 寻找子菜单的父类
function findMenuParent(tag) {
  const tagCurrent = []
  // const menu = store.getters.menu
  tagCurrent.push(tag)
  return tagCurrent
}

router.afterEach(() => {
  setTimeout(() => {
    const tag = store.getters.tag
    // setTitle(tag.label)
    store.commit('tags/SET_TAG_CURRENT', findMenuParent(tag))
  }, 0)
})

router.beforeEach((to, from, next) => {
  const value = to.query.src ? to.query.src : to.path
  const label = to.query.name ? to.query.name : to.name
  const name = to.meta.title
  // console.log('caccccc', to)
  if (whiteList.indexOf(value) === -1) {
    store.commit('tags/ADD_TAG', {
      label: label,
      value: value,
      query: to.query,
      name: name
    })
  }
  next()
})

Vue.config.productionTip = false

// 小高 在Vue的原型上创建一个属性bus   用作看板项目  项目管理   该属性的值为new Vue（），即bus也是一个vue实例  打扰了
Vue.prototype.bus = new Vue()

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
